[openrtm-commit:01772] r672 - trunk/OpenRTM-aist-Python/OpenRTM_aist

openrtm @ openrtm.org openrtm @ openrtm.org
2016年 2月 27日 (土) 11:04:40 JST


Author: miyamoto
Date: 2016-02-27 11:04:40 +0900 (Sat, 27 Feb 2016)
New Revision: 672

Modified:
   trunk/OpenRTM-aist-Python/OpenRTM_aist/CORBA_RTCUtil.py
Log:
	
[compat,bugfix,->RELENG_1_2] bug fix. refs #3400

Modified: trunk/OpenRTM-aist-Python/OpenRTM_aist/CORBA_RTCUtil.py
===================================================================
--- trunk/OpenRTM-aist-Python/OpenRTM_aist/CORBA_RTCUtil.py	2016-02-27 01:52:14 UTC (rev 671)
+++ trunk/OpenRTM-aist-Python/OpenRTM_aist/CORBA_RTCUtil.py	2016-02-27 02:04:40 UTC (rev 672)
@@ -266,25 +266,26 @@
 # 
 # @param rtc 対象のRTコンポーネント
 # @param ec_id 実行コンテキストのID
-# @param ret RTCの状態
+# @param state RTCの状態
 # @return rtc、ecがnilの場合はFalseを返す。
-# nilではない場合はret[0]に状態を代入してTrueを返す。
+# nilではない場合はstate[0]に状態を代入してTrueを返す。
 #
 # @else
 #
 # @brief 
 # @param rtc
 # @param ec_id
+# @param state 
 # @return 
 #
 # @endif
-def get_state(rtc, ec_id=0, ret=[None]):
+def get_state(rtc, ec_id=0, state=[None]):
   if CORBA.is_nil(rtc):
     return False
   ec = get_actual_ec(rtc, ec_id)
   if CORBA.is_nil(ec):
     return False
-  ret[0] = ec.get_component_state(rtc)
+  state[0] = ec.get_component_state(rtc)
   return True
 
 ##
@@ -659,20 +660,20 @@
 #
 # 
 # @param rtc RTコンポーネント
-# @param name ポート名
+# @param port_name ポート名
 # @return ポート
 #
 # @else
 #
 # @brief 
 # @param rtc 
-# @param name
+# @param port_name
 # @return 
 #
 # @endif
 #
-# RTC::PortService_var get_port_by_name(const RTC::RTObject_ptr rtc, std::string name)
-def get_port_by_name(rtc, name):
+# RTC::PortService_var get_port_by_name(const RTC::RTObject_ptr rtc, std::string port_name)
+def get_port_by_name(rtc, port_name):
   if CORBA.is_nil(rtc):
     return RTC.PortService._nil
   ports = rtc.get_ports()
@@ -680,7 +681,7 @@
     pp = p.get_port_profile()
     s = pp.name
     
-    if name == s:
+    if port_name == s:
       return p
 
   return RTC.PortService._nil



More information about the openrtm-commit mailing list